summaryrefslogtreecommitdiff
path: root/include/m_message.h
diff options
context:
space:
mode:
authorGeorge Hazan <ghazan@miranda.im>2018-04-04 16:02:56 +0300
committerGeorge Hazan <ghazan@miranda.im>2018-04-04 16:02:56 +0300
commite230d5b323f08f9bf07cfd4822f22a22c22660b7 (patch)
treeab84396539f13100ba119cbc5b2575b374c8f503 /include/m_message.h
parent8937c49faab219b51b9863847406a21945d3a9cb (diff)
fix for adding separators into SRMM toolbar
Diffstat (limited to 'include/m_message.h')
-rw-r--r--include/m_message.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/m_message.h b/include/m_message.h
index d21bed5c7c..7c33127ce9 100644
--- a/include/m_message.h
+++ b/include/m_message.h
@@ -240,8 +240,8 @@ struct BBButton
};
// adds a new toolbar button
-// returns 0 on success and nonzero value otherwise
-EXTERN_C MIR_APP_DLL(int) Srmm_AddButton(const BBButton *bbdi, int = hLangpack);
+// returns button's handle on success or NULL otherwise
+EXTERN_C MIR_APP_DLL(HANDLE) Srmm_AddButton(const BBButton *bbdi, int = hLangpack);
// modifies the existing toolbar button
// returns 0 on success and nonzero value otherwise